"ImputeStat"(object, method = c("Cox", "weibull", "exponential")[1], formula = NULL, ...)
"ImputeStat"(object, method = c("Cox", "weibull", "exponential")[1], formula = NULL, ..., parallel = c("no", "multicore", "snow")[1], ncpus = 1L, cl = NULL)
ImputeStat(object, method = c("logrank", "Wilcoxon", "Cox", "weibull", "exponential")[1], formula, ...)
"ImputeStat"(object, method = c("logrank", "Wilcoxon", "Cox")[1], formula = NULL, ..., parallel = c("no", "multicore", "snow")[1], ncpus = 1L, cl = NULL)ScoreImputedData, ScoreImputedSet, GammaImputedData or GammaImputedSet object
to fit the model tosurvival::survdiff
"Wilcoxon": Peto & Peto modification of the Gehan-Wilcoxon test using survival::survdiff
with rho=1
"Cox": Fit a cox model using survival::coxph For gamma imputation the model can be "Cox" (using survival::coxph),
"weibull" or "exponential" both using survival::coxph
~ treatment.group and for gamma imputation
this is the formula used when fitting the Cox modelFor method="Cox", additional covariates can be included by explictily giving a
formula argument. For logrank/Wilcoxon only additional strata terms can be
included.
In all cases only the right hand side of the formula is required
The survival object on the left hand side is created automatically
E.g. for a Cox model could use formula=~arm + covar1. The cluster and tt options cannot be used
See the vignettes for further details
GammaImputedSet and ScoreImputedSetGammaImputedSet and ScoreImputedSet.parallel="snow". If not supplied, a
cluster on the local machine is created for the duration of the call, can be used for GammaImputedSet and ScoreImputedSet.ScoreStat.object ScoreImputedData.object