The (maximum) number of subjects to be included in the
risk set
w.censoring
The weighting on the censoring risk score when
calculating distances for the nearest neighbour calculation
A weighting of (1-w.censoring) is used for the event risk score
min.subjects
If using time dependent score imputation include at least
this number of subjects when fitting the Cox model (i.e. include some subjects who were censored/had event
earlier than the cenosred observation if neccessary)
Value
A list of options used within the ScoreImputedData
function