censor.type
column name of the column containing the reason for censoring,
0=had event, 1=non-administrative censoring 2=administrative censoring -- only subjects
with 1 in this column count as having an `event' in the Cox model for censoring
(optionally used -- if not used then all subjects who are censored are used)